==> keggorthology_2.2.0.zip: keggorthology/doc/keggorth.R <==
###################################################
### chunk number 1: lkkog
###################################################
#line 61 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
library(keggorthology)
library(graph)
data(KOgraph)
KOgraph
nodes(KOgraph)[1:5]


###################################################
### chunk number 2: lkr
###################################################
#line 69 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
adj(KOgraph, nodes(KOgraph)[1])


###################################################
### chunk number 3: lkpa
###################################################
#line 77 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
library(RBGL)
sp.between(KOgraph, nodes(KOgraph)[1], "PPAR signaling pathway")


###################################################
### chunk number 4: lkta
###################################################
#line 84 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
nodeData(KOgraph,,"tag")[1:5]


###################################################
### chunk number 5: lkde
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
nodeData(KOgraph,,"depth")[1:5]


###################################################
### chunk number 6: lkd
###################################################
#line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
getKOtags("insulin")


###################################################
### chunk number 7: lkp
###################################################
#line 104 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
library(hgu95av2.db)
mp = getKOprobes("Methionine")
library(ALL)
data(ALL)
ALL[mp,]


###################################################
### chunk number 8: lksi
###################################################
#line 124 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHdErpx/R.INSTALL6c0a3307/keggorthology/inst/doc/keggorth.Rnw"
sessionInfo()

==> keggorthology_2.4.0.zip: keggorthology/doc/keggorth.R <==
###################################################
### chunk number 1: lkkog
###################################################
#line 61 "keggorth.Rnw"
library(keggorthology)
library(graph)
data(KOgraph)
KOgraph
nodes(KOgraph)[1:5]


###################################################
### chunk number 2: lkr
###################################################
#line 69 "keggorth.Rnw"
adj(KOgraph, nodes(KOgraph)[1])


###################################################
### chunk number 3: lkpa
###################################################
#line 77 "keggorth.Rnw"
library(RBGL)
sp.between(KOgraph, nodes(KOgraph)[1], "PPAR signaling pathway")


###################################################
### chunk number 4: lkta
###################################################
#line 84 "keggorth.Rnw"
nodeData(KOgraph,,"tag")[1:5]


###################################################
### chunk number 5: lkde
###################################################
#line 88 "keggorth.Rnw"
nodeData(KOgraph,,"depth")[1:5]


###################################################
### chunk number 6: lkd
###################################################
#line 98 "keggorth.Rnw"
getKOtags("insulin")


###################################################
### chunk number 7: lkp
###################################################
#line 104 "keggorth.Rnw"
library(hgu95av2.db)
mp = getKOprobes("Methionine")
library(ALL)
data(ALL)
ALL[mp,]


###################################################
### chunk number 8: lksi
###################################################
#line 124 "keggorth.Rnw"
sessionInfo()
